@@ -1,11 +1,6 @@
-import logging
-
 from ..core.constants import MemberLevel
 from enum import Enum, unique
 
-logger = logging.getLogger(__name__)
-
-
 DISTRIBUTE_ERROR_CODE_PREFIX = 246000
 BASE_DISTRIBUTE_API_CODE = 20103000
 
@@ -443,6 +438,7 @@ class DistributeStatus(object):
         CUS_CONFIRM,
         CUS_CONFIRM_AT_GUIDE,
         CUS_CONFIRM_AT_CUSSERVICE,
+        OUTSTORAGE_PACKAGED,
     ]
 
     # 未售后的不支持修改配送方式的发货单状态
@@ -456,7 +452,7 @@ class DistributeStatus(object):
     ]
 
 
-class __ShippingMethod(object):
+class ShippingMethod(object):
     # 普通快递
     EXPRESS = 'express'
     # 自提
@@ -464,20 +460,6 @@ class __ShippingMethod(object):
     # 闪送
     FLASH_DELIVERY = 'flash_delivery'
 
-    CHOICES = (
-        (EXPRESS, "快递发货"),
-        (SELF_SERVICE, "到店自提"),
-        (FLASH_DELIVERY, "闪送"),
-    )
-
-    def __getattribute__(self, name: str):
-        value = super().__getattribute__(name)
-        logger.warning("sparrow_distribute.constants.ShippingMethod 已废弃, 请使用 sparrow_order_lib.core.constants.ShippingMethod 替换")
-        return value
-
-
-ShippingMethod = __ShippingMethod()
-
 
 class DistributeEventConstKey(object):
     FROM_STATUS_LIST_KEY = "from_status_list"
